@@ -1098,7 +1098,7 @@ get_child_environment (TerminalScreen *screen,
     {
       /* FIXME: moving the tab between windows, or the window between displays will make the next two invalid... */
       g_hash_table_replace (env_table, g_strdup ("WINDOWID"),
-			    g_strdup_printf ("%ld",
+			    g_strdup_printf ("%lu",
 					     GDK_WINDOW_XID (gtk_widget_get_window (window))));
       g_hash_table_replace (env_table, g_strdup ("DISPLAY"), g_strdup (gdk_display_get_name (gtk_widget_get_display (window))));
     }
